/* 
 * File:   oled_c.h
 * Author: barna
 *
 * Created on August 17, 2015, 2:40 PM
 */

#ifndef OLED_C_H
#define	OLED_C_H

#ifdef	__cplusplus
extern "C" {
#endif

#define SEPS114A_SOFT_RESET 0x01
#define SEPS114A_DISPLAY_ON_OFF 0x02
#define SEPS114A_ANALOG_CONTROL 0x0F
#define SEPS114A_STANDBY_ON_OFF 0x14
#define SEPS114A_OSC_ADJUST 0x1A
#define SEPS114A_ROW_SCAN_DIRECTION 0x09
#define SEPS114A_DISPLAY_X1 0x30
#define SEPS114A_DISPLAY_X2 0x31
#define SEPS114A_DISPLAY_Y1 0x32
#define SEPS114A_DISPLAY_Y2 0x33
#define SEPS114A_DISPLAYSTART_X 0x38
#define SEPS114A_DISPLAYSTART_Y 0x39
#define SEPS114A_CPU_IF 0x0D
#define SEPS114A_MEM_X1 0x34
#define SEPS114A_MEM_X2 0x35
#define SEPS114A_MEM_Y1 0x36
#define SEPS114A_MEM_Y2 0x37
#define SEPS114A_MEMORY_WRITE_READ 0x1D
#define SEPS114A_DDRAM_DATA_ACCESS_PORT 0x08
#define SEPS114A_DISCHARGE_TIME 0x18
#define SEPS114A_PEAK_PULSE_DELAY 0x16
#define SEPS114A_PEAK_PULSE_WIDTH_R 0x3A
#define SEPS114A_PEAK_PULSE_WIDTH_G 0x3B
#define SEPS114A_PEAK_PULSE_WIDTH_B 0x3C
#define SEPS114A_PRECHARGE_CURRENT_R 0x3D
#define SEPS114A_PRECHARGE_CURRENT_G 0x3E
#define SEPS114A_PRECHARGE_CURRENT_B 0x3F
#define SEPS114A_COLUMN_CURRENT_R 0x40
#define SEPS114A_COLUMN_CURRENT_G 0x41
#define SEPS114A_COLUMN_CURRENT_B 0x42
#define SEPS114A_ROW_OVERLAP 0x48
#define SEPS114A_SCAN_OFF_LEVEL 0x49
#define SEPS114A_ROW_SCAN_ON_OFF 0x17
#define SEPS114A_ROW_SCAN_MODE 0x13
#define SEPS114A_SCREEN_SAVER_CONTROL 0xD0
#define SEPS114A_SS_SLEEP_TIMER 0xD1
#define SEPS114A_SCREEN_SAVER_MODE 0xD2
#define SEPS114A_SS_UPDATE_TIMER 0xD3
#define SEPS114A_RGB_IF 0xE0
#define SEPS114A_RGB_POL 0xE1
#define SEPS114A_DISPLAY_MODE_CONTROL 0xE5

#define SEPS114A_WIDTH  0x60        //96 pixel
#define SEPS114A_HEIGHT 0x60        //96 pixel

#define X_AXIS  0x00
#define Y_AXIS  0x01

#define NOT_FLIPPED 0x00
#define FLIPPED     0x01

#define ORIENTATION_NORMAL   0x00   // zero is top left corner, y axis is vertical
#define ORIENTATION_LEFT     0x01   // zero is bottom left corner, x axis is vertical
#define ORIENTATION_RIGHT    0x02   // zero is top right corner, x axis is vertical
#define ORIENTATION_DOWN     0x03   // zero is bottom right corner, y axis is vertical
#define ORIENTATION_ORIGINAL 0xFF   // zero is top right corner, y axis is vertical (mirrored!)

const uint16_t C_BLACK   = 0x0000;
const uint16_t C_WHITE   = 0xFFFF;
const uint16_t C_BLUE    = 0x001F;
const uint16_t C_GREEN   = 0x07E0;
const uint16_t C_RED     = 0xF800;

typedef struct point{
    uint8_t x;
    uint8_t y;
} point;

void OLED_C_command(unsigned char reg_index, unsigned char reg_value);

void OLED_C_data(unsigned char data_value);

void OLED_C_Init(uint8_t orientation);

void DDRAM_access();

void OLED_C_MemorySize(point p1, point p2);

void OLED_C_Color(char colorMSB, char colorLSB );

void OLED_C_Background(const uint16_t color);

void OLED_C_print_char(point p, const unsigned char ch, const uint16_t color);

void OLED_C_print(point p, const unsigned char ch[], const uint16_t color);

void OLED_C_dot(point p, const uint16_t color);

void OLED_C_rect(point p1, point p2, const uint16_t color);

int length(const unsigned char array[]);

void delay_ms(int msec);

uint16_t getBackgroundColor();

point getRealPos(point original);

#ifdef	__cplusplus
}
#endif

#endif	/* OLED_C_H */

